@@ -1,17 +1,17 @@
 import os
 import sys
 
-from python_agent.packages import requests
-from python_agent.packages.requests.packages.urllib3.exceptions import InsecureRequestWarning
+from python_agent.packages import urllib3
+from python_agent.packages.urllib3.exceptions import InsecureRequestWarning
 
 if sys.version_info < (2, 7):
     from python_agent.packages.dictconfig import dictConfig
 else:
     from logging.config import dictConfig
 
-requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
+urllib3.disable_warnings(InsecureRequestWarning)
 
-__version__ = "0.2.167"
+__version__ = "0.2.230"
 __package_name__ = "sealights-python-agent"
 
 
@@ -32,29 +32,9 @@ LOG_CONF = {
             'level': 'DEBUG',
             'formatter': 'standard',
             'stream': 'ext://sys.stdout',
-        },
-        'sealights-console': {
-            'class': 'logging.StreamHandler',
-            'level': 'DEBUG' if os.environ.get("SL_DEBUG") else 'INFO',
-            'formatter': 'sealights-standard',
-            'stream': 'ext://sys.stdout',
-        },
-        'sealights-file': {
-            'class': 'logging.handlers.RotatingFileHandler',
-            'level': 'DEBUG' if os.environ.get("SL_DEBUG") else 'INFO',
-            'formatter': 'sealights-standard',
-            'filename': 'sealights-python-agent.log',
-            'mode': 'a',
-            'maxBytes': 10485760,
-            'backupCount': 10,
         }
     },
     'loggers': {
-        'python_agent': {
-            'handlers': ['sealights-console', 'sealights-file'] if os.environ.get("SL_DEBUG") else [],
-            'level': 'DEBUG' if os.environ.get("SL_DEBUG") else 'INFO',
-            'propagate': False
-        },
         '__main__': {
             'handlers': ['cli'],
             'level': 'DEBUG',
@@ -90,7 +70,7 @@ LOG_CONF = {
             'level': 'DEBUG',
             'propagate': True
         },
-        'python_agent.packages.requests.packages.urllib3.connectionpool': {
+        'python_agent.packages.urllib3.connectionpool': {
             'handlers': [],
             'level': 'WARN',
             'propagate': False
@@ -107,4 +87,30 @@ LOG_CONF = {
         }
     }
 }
+if os.environ.get("SL_DEBUG"):
+    LOG_CONF["handlers"].update({
+        'sealights-console': {
+            'class': 'logging.StreamHandler',
+            'level': 'DEBUG',
+            'formatter': 'sealights-standard',
+            'stream': 'ext://sys.stdout',
+        },
+        'sealights-file': {
+            'class': 'logging.handlers.RotatingFileHandler',
+            'level': 'DEBUG',
+            'formatter': 'sealights-standard',
+            'filename': 'sealights-python-agent.log',
+            'mode': 'a',
+            'maxBytes': 10485760,
+            'backupCount': 10,
+        }
+    })
+    LOG_CONF["loggers"].update({
+        'python_agent': {
+            'handlers': ['sealights-console', 'sealights-file'],
+            'level': 'DEBUG',
+            'propagate': False
+        }
+    })
+
 dictConfig(LOG_CONF)
